summaryrefslogtreecommitdiff
path: root/plugins/externaltools/tools/library.py
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/externaltools/tools/library.py')
-rwxr-xr-xplugins/externaltools/tools/library.py20
1 files changed, 10 insertions, 10 deletions
diff --git a/plugins/externaltools/tools/library.py b/plugins/externaltools/tools/library.py
index 6eb6ff1a..e3dc624c 100755
--- a/plugins/externaltools/tools/library.py
+++ b/plugins/externaltools/tools/library.py
@@ -1,5 +1,5 @@
# -*- coding: utf-8 -*-
# Gedit External Tools plugin
# Copyright (C) 2006 Steve Frécinaux <[email protected]>
#
# This program is free software; you can redistribute it and/or modify
@@ -41,19 +41,19 @@ class ToolLibrary(Singleton):
if platform.platform() != 'Windows':
for d in self.get_xdg_data_dirs():
- self.locations.append(os.path.join(d, 'gedit-2', 'plugins', 'externaltools', 'tools'))
+ self.locations.append(os.path.join(d, 'pluma-2', 'plugins', 'externaltools', 'tools'))
self.locations.append(datadir)
# self.locations[0] is where we save the custom scripts
if platform.platform() == 'Windows':
- toolsdir = os.path.expanduser('~/gedit/tools')
+ toolsdir = os.path.expanduser('~/pluma/tools')
else:
userdir = os.getenv('MATE22_USER_DIR')
if userdir:
- toolsdir = os.path.join(userdir, 'gedit/tools')
+ toolsdir = os.path.join(userdir, 'pluma/tools')
else:
- toolsdir = os.path.expanduser('~/.mate2/gedit/tools')
+ toolsdir = os.path.expanduser('~/.mate2/pluma/tools')
self.locations.insert(0, toolsdir);
@@ -80,9 +80,9 @@ class ToolLibrary(Singleton):
import xml.etree.ElementTree as et
userdir = os.getenv('MATE22_USER_DIR')
if userdir:
- filename = os.path.join(userdir, 'gedit/gedit-tools.xml')
+ filename = os.path.join(userdir, 'pluma/pluma-tools.xml')
else:
- filename = os.path.expanduser('~/.mate2/gedit/gedit-tools.xml')
+ filename = os.path.expanduser('~/.mate2/pluma/pluma-tools.xml')
if not os.path.isfile(filename):
return
@@ -250,7 +250,7 @@ class Tool(object):
for line in fp:
if not in_block:
- in_block = line.startswith('# [Gedit Tool]')
+ in_block = line.startswith('# [Pluma Tool]')
continue
if line.startswith('##') or line.startswith('# #'): continue
if not line.startswith('# '): break
@@ -389,7 +389,7 @@ class Tool(object):
# before entering the data block
for line in fp:
- if line.startswith('# [Gedit Tool]'):
+ if line.startswith('# [Pluma Tool]'):
break
lines.append(line)
# in the block:
@@ -407,7 +407,7 @@ class Tool(object):
return lines
def _dump_properties(self):
- lines = ['# [Gedit Tool]']
+ lines = ['# [Pluma Tool]']
for item in self._properties.iteritems():
if item[0] in self._transform:
lines.append('# %s=%s' % (item[0], self._transform[item[0]][1](item[1])))
@@ -1,5 +1,5 @@
# -*- coding: utf-8 -*-
-# Gedit External Tools plugin
+# Pluma External Tools plugin
# Copyright (C) 2006 Steve Frécinaux <[email protected]>
#